==> zen-crunch-core-0.2.9.tgz: package/README.md <==
[![pipeline status](http://gitlab.zenatix.com/zenatix/zen-crunch-core/badges/master/pipeline.svg)](http://gitlab.zenatix.com/zenatix/zen-crunch-core/commits/master)
[![npm version](https://badge.fury.io/js/zen-crunch-core.svg)](https://badge.fury.io/js/zen-crunch-core)
### Zen Crunch Core

#### Description
This lib is the Base crunching library with business logic and specific options to run with table and Charts

#### Features
1. Parse Flat multi-dimensional data
1. Apply Multi-dimensional filters on data
1. Custom functions to get attribute on Single and multiple keys at once
1. Custom function to generate Any operator you wish
and many more ...


#### Dev notes
Fully Automated Commit and tagging and CI integrated. Semver Followed. To setup and develop on this libs please follow these steps

##### Prerequisites
1. Nodejs 6+ and npm 5+ is needed

##### Steps to setup ENV
1. Clone Repo
    - `git clone git@gitlab.zenatix.com:zenatix/zen-crunch-core.git`
    - `npm install`
1. Run - `sudo npm install -g release-it`
1. Testing test cases `npm t`
1. Testing release locally
    1. Use - `npm run build && npm pack` to create a tar of package
    1. Install this tar in main repo by `npm install <path to file>` 
1. Commit system just commits all staged files.
    - You can manually stage files
    - To stage all files. Run `npm run stage:all`
1. Create release
    - Patch release - `npm run release:patch`
    - Minor release - `npm run release:minor`
    - Major release - `npm run release:major`

Maintained By - Zenatix Solutions. 

Peace

==> zen-crunch-core-0.2.13.tgz: package/README.md <==
[![pipeline status](http://gitlab.zenatix.com/zenatix/zen-crunch-core/badges/master/pipeline.svg)](http://gitlab.zenatix.com/zenatix/zen-crunch-core/commits/master)
[![npm version](https://badge.fury.io/js/zen-crunch-core.svg)](https://badge.fury.io/js/zen-crunch-core)
### Zen Crunch Core

#### Description
This lib is the Base crunching library with business logic and specific options to run with table and Charts

#### Features
1. Parse Flat multi-dimensional data
1. Apply Multi-dimensional filters on data
1. Custom functions to get attribute on Single and multiple keys at once
1. Custom function to generate Any operator you wish
and many more ...


#### Dev notes
CLI tools for Commit, Tagging are included Please Use ths only. Docs and CI integrated. Semver Followed. To setup and develop on this libs please follow these steps

##### Prerequisites
1. Nodejs 6+ and npm 5+ is needed

##### Steps to setup ENV
1. Clone Repo
    - `git clone git@gitlab.zenatix.com:zenatix/zen-crunch-core.git`
    - `npm install`
1. Run - `sudo npm install -g release-it`
1. Testing test cases `npm t`
1. Testing release locally
    1. Use - `npm run build && npm pack` to create a tar of package
    1. Install this tar in main repo by `npm install <path to file>` 
1. Commit system just commits all staged files.
    - You can manually stage files
    - To stage all files. Run `npm run stage:all`
1. Create release
    - Patch release - `npm run release:patch`
    - Minor release - `npm run release:minor`
    - Major release - `npm run release:major`
1. Follow Function Documentation in JSDOC format

Maintained By - Zenatix Solutions. 

Peace
